@@ -7,57 +7,14 @@ from Cookie import SimpleCookie
 from django.utils.cache import get_max_age, patch_response_headers
 from django.http import HttpResponse
 import sys
-from django.utils import log
+from django.utils.log import getLogger
 from django.contrib import messages
-import time
 
 
-LAST_UPDATE_KEY_PREFIX = getattr(settings, "LAST_UPDATE_KEY_PREFIX", "LAST_UPDATE_TIMESTAMP")
+logger = getLogger("PyLucidCacheMiddleware")
+#logger.setLevel(logging.DEBUG)
+#logger.addHandler(logging.StreamHandler())
 
-logger = log.getLogger("PyLucidCacheMiddleware")
-
-if "runserver" in sys.argv or "tests" in sys.argv:
-    log.logging.basicConfig(format='%(created)f pid:%(process)d %(message)s')
-    logger.setLevel(log.logging.DEBUG)
-    logger.addHandler(log.logging.StreamHandler())
-
-if not logger.handlers:
-    # ensures we don't get any 'No handlers could be found...' messages
-    logger.addHandler(log.NullHandler())
-
-
-def build_cache_key(request, url):
-    """
-    Build the cache key based on the url and:
-    
-    * LANGUAGE_CODE: The language code in the url can be different than the
-        used language for gettext translation.
-    * SITE_ID: request.path is the url without the domain name. So the same
-        url in site A and B would result in a collision.
-    """
-    try:
-        language_code = request.LANGUAGE_CODE # set in django.middleware.locale.LocaleMiddleware
-    except AttributeError:
-        etype, evalue, etb = sys.exc_info()
-        evalue = etype("%s (django.middleware.locale.LocaleMiddleware must be insert before cache middleware!)" % evalue)
-        raise etype, evalue, etb
-
-    site_id = settings.SITE_ID
-    cache_key = "%s:%s:%s" % (url, language_code, site_id)
-    logger.debug("Cache key: %r" % cache_key)
-    return cache_key
-
-
-def delete_cache_entry(request, url):
-    """ Delete a url from cache """
-    cache_key = build_cache_key(request, url)
-    if settings.DEBUG:
-        test = cache.get(cache_key)
-        if test is None:
-            logger.warn("Cache key %r not found!" % cache_key)
-        else:
-            logger.debug("Delete %r from cache, ok." % cache_key)
-    cache.delete(cache_key)
 
 
 class PyLucidCacheMiddlewareBase(object):
@@ -69,7 +26,7 @@ class PyLucidCacheMiddlewareBase(object):
             # Don't cache PyLucid get views
             logger.debug("Don't cache request with GET parameter: %s" % repr(request.GET))
             return False
-        if settings.RUN_WITH_DEV_SERVER and request.path.startswith(settings.MEDIA_URL):
+        if settings.RUN_WITH_DEV_SERVER and request.path.startswith(settings.STATIC_URL):
             logger.debug("Don't cache static files in dev server")
             return False
 
@@ -89,12 +46,27 @@ class PyLucidCacheMiddlewareBase(object):
         return True
 
     def get_cache_key(self, request):
-        """ return cache key for the current request.path """
-        url = request.path
-        return build_cache_key(request, url)
+        """
+        Build the cache key based on the url and:
+        
+        * LANGUAGE_CODE: The language code in the url can be different than the
+            used language for gettext translation.
+        * SITE_ID: request.path is the url without the domain name. So the same
+            url in site A and B would result in a collision.
+        """
+        path = request.path
 
-def set_last_update_timestamp(site_id):
-    cache_key = "%s:%s:%s" % (LAST_UPDATE_KEY_PREFIX, site_id)
+        try:
+            language_code = request.LANGUAGE_CODE # set in django.middleware.locale.LocaleMiddleware
+        except AttributeError:
+            etype, evalue, etb = sys.exc_info()
+            evalue = etype("%s (django.middleware.locale.LocaleMiddleware must be insert before cache middleware!)" % evalue)
+            raise etype, evalue, etb
+
+        site_id = settings.SITE_ID
+        cache_key = "%s:%s:%s" % (path, language_code, site_id)
+        logger.debug("Cache key: %r" % cache_key)
+        return cache_key
 
 
 class PyLucidFetchFromCacheMiddleware(PyLucidCacheMiddlewareBase):
@@ -109,9 +81,7 @@ class PyLucidFetchFromCacheMiddleware(PyLucidCacheMiddlewareBase):
         cache_key = self.get_cache_key(request)
         response = cache.get(cache_key)
         if response is not None: # cache hit
-            timestamp = response.cache_timestamp
-            age = time.time() - timestamp
-            logger.debug("Use %r from cache (Age: %s)" % (cache_key, age))
+            logger.debug("Use %r from cache!" % cache_key)
             response._from_cache = True
             return response
 
@@ -161,7 +131,6 @@ class PyLucidUpdateCacheMiddleware(PyLucidCacheMiddlewareBase):
         patch_response_headers(response2, timeout)
 
         cache_key = self.get_cache_key(request)
-        response2.cache_timestamp = time.time()
         cache.set(cache_key, response2, timeout)
 
         logger.debug("Put to cache: %r" % cache_key)
